==> sage-client-1.1.4.tgz: package/src/executors/sage-bgp-executor.js <==
/* file : sage-bgp-executor.js
MIT License

Copyright (c) 2018 Thomas Minier

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
*/

'use strict'

const { BGPExecutor } = require('sparql-engine').executors
const BindJoinOperator = require('../operators/bindjoin-operator.js')

/**
 * Evaluate Basic Graph patterns using a Sage server
 * @extends BGPExecutor
 * @author Thomas Minier
 * @author Corentin Marionneau
 */
class SageBGPExecutor extends BGPExecutor {
  _execute (source, graph, patterns, options, isJoinIdentity) {
    if (isJoinIdentity) {
      return super._execute(source, graph, patterns, options, true)
    }
    return new BindJoinOperator(source, patterns, graph, options)
  }
}

module.exports = SageBGPExecutor

==> sage-client-1.3.0.tgz: package/src/executors/sage-bgp-executor.js <==
/* file : sage-bgp-executor.js
MIT License

Copyright (c) 2018 Thomas Minier

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
*/

'use strict'

const { BGPExecutor } = require('sparql-engine')
const boundJoin = require('../operators/bound-join.js')

/**
 * Evaluate Basic Graph patterns using a Sage server
 * @extends BGPExecutor
 * @author Thomas Minier
 * @author Corentin Marionneau
 */
class SageBGPExecutor extends BGPExecutor {
  _execute (source, graph, patterns, options, isJoinIdentity) {
    return boundJoin(source, patterns, graph, options)
  }
}

module.exports = SageBGPExecutor
